//
//	NetworkStat.js
//	Widgets
/*

Copyright 2005/2006, Pascal Pfiffner.

*/


// Globals
// default-settings: 'whilehidden', 7200, false

var seconds = getTimer();		// seconds left till next refresh
var refreshMode = getRefreshMode();			// refresh-mode
var refreshOnShow = getRefreshOnShow();		// refresh on every Dashboard-activation?
var stylesheet = getStylesheet();

var pingIP = getPingIP();					// get the IP the user wants to ping

var doCountdown = (refreshMode == 'manual') ? 0 : 1;		// countdown active or not?
var lastRefresh = new Date();
var currentLocation = "unknown";
var the_interval;
var no_network_tries = 0;				// if no network is present, raise this one and retry after 10, 20 or 30 seconds. If after 3 tries no network is there, give up.



function showVersion() {
	document.getElementById('infospan').innerHTML = "version 1.3";
}


// Dashboard Setup by Apple (sets the stylesheet, creates the "done" button and refreshes for the first time)
function setup() {
	setStylesheet(stylesheet);		// set stylesheet matching prefs
	document.getElementById('refreshbutton').src = "Images_" + stylesheet + "/refresh.png";	// set refreshbutton matching stylesheet
	createGenericButton(document.getElementById("done"), "done", savePrefs);
	
	switchPrefTab("refresh");
	
	// refresh state
	setTimeout("refreshState()", 100);
}


//	Main Functions

function refreshState() {		// refresh info
	setTimer("in progress...");
	window.clearInterval(the_interval);
	var no_net = false;
	
	if(window.widget) {
		
		// Location
		setupLocations();
		document.getElementById("change_location_cover").src = "Images_" + stylesheet + "/Home.png";
		
		purgeInterfaces();
		
		// Internal
		addParagraph("checking...", "None");	// add the checking-indicator
		adjustTotalSize();						// adjusts widget size
		var internals = widget.system("./get_internal.pl", null).outputString;
		var interfaces = internals.split("|");
		purgeLastChild("maincontent");
		
		var iface_count = 0;
		var iparr = new Array();
		for(i = 0; i < interfaces.length; i++) {
			if(interfaces[i].length > 0) {
				var parts = interfaces[i].split("?");		// 0 = interface, 1 = IPv4, 2 = IPv6, 3 = prefixlen, 4 = netmask, 5 = broadcast, 6 = MAC
				addParagraph(parts[1], parts[0], 0);
				if(parts[2])
					addParagraph(new Array(parts[2], parts[3], parts[4], parts[5], parts[6]), 0, "interface_more");
				iparr[iface_count] = parts[1];
				iface_count++;
			}
		}
		
		
		// External
		addParagraph("checking...", "Internet", 0);		// adds another checking-indicator
		adjustTotalSize();								// the checking-indicator should be inside the widget
		var external = widget.system("/usr/bin/curl --connect-timeout 8 -s www.whatismyip.org", null).outputString;
		if(external) {
			purgeLastChild("maincontent");
			//if( ! (iface_count == 1 && iparr[0] == external))		// only add external if it`s not the same as the single internal IP
			addParagraph(external, "Internet", 0);
			
			// Ping
			addParagraph(0, 0, "interface_more");
			//toggleMoreInfo(document.getElementById("maincontent").lastChild.previousSibling, event);
			setTimeout("startJSPing()", 100);
		}
		else {
			no_net = true;
			external = "no network";
			purgeLastChild("maincontent");
			if( ! (iface_count == 1 && iparr[0] == external))		// only add external if it`s not the same as the one single internal IP
				addParagraph(external, "Internet", 0);
		}
	}
	
	
	// No Widget
	else {
		displayLocation("still unknown");
		
		purgeInterfaces();
		addParagraph("checked but unknown", "None", 0);
	}
	
	adjustTotalSize();
	setTimer("done");		// set the timer (countdown will reset it in a second, but lets do that anyway)
	
	lastRefresh = new Date();
	document.getElementById("lastRefresh").innerHTML = formatDate(lastRefresh);
	
	// recheck if there was no WAN
	if(no_net) {
		no_network_tries++;
		
		if(no_network_tries <= 3) {
			seconds = no_network_tries * 10;
			countdown();
			return;
		}
	}
	
	no_network_tries = 0;
	
	seconds = getTimer();
	countdown();
}


// calls the shell script
var pingResult;
function startJSPing() {
	if(window.widget) {
		if(!pingIP)
			pingIP = "4.2.2.2";
		
		document.getElementById("ping_packets").innerHTML = "ping in progress...";
		try {
			pingResult = widget.system("./ping.sh " + pingIP, displayJSPing);
		}
		catch(exc) {
			alert("error while pinging");
		}
	}
	
	return false;
}

// gets the result from startJSPing and displays it
function displayJSPing() {
	if(pingResult.outputString && document.getElementById("ping_packets")) {
		var arr = pingResult.outputString.split(/\/| /);
		
		document.getElementById("ping_packets").innerHTML = Math.abs((arr[1] / arr[0]) * 100) + "% of " + arr[0] + " packets received";
		document.getElementById("ping_min").innerHTML = arr[2];
		document.getElementById("ping_avg").innerHTML = arr[3];
		document.getElementById("ping_max").innerHTML = arr[4];
	}
}


function countdown() {		// display time left to refresh and initiate refresh on t=0
	if(doCountdown && (refreshMode != 'manual')) {
		if(seconds > 3600) {
			if(seconds % 3600 == 0)
				setTimer("in " + (seconds/3600) + " hours");
			else {
				var hours = Math.floor(seconds / 3600);
				var minutes = Math.floor((seconds % 3600) / 60);
				setTimer("in " + hours + ((hours == 1) ? " hour" : " hours") + " " + minutes + ((minutes == 1) ? " minute" : " minutes"));
			}
			
			seconds -= 60;
			
			window.clearInterval(the_interval);
			the_interval = window.setInterval("countdown()", 60000);
		}
		
		else if(seconds > 60) {
			setTimer("in about " + Math.ceil(seconds / 60) + " minutes");
			
			seconds -= 60;
			if(seconds < 60)
				seconds = 60;
			
			window.clearInterval(the_interval);
			the_interval = window.setInterval("countdown()", 60000);
		}
		
		else if(seconds > 0) {
			setTimer("in " + seconds + ((seconds == 1) ? " second" : " seconds"));
			seconds--;
			
			window.clearInterval(the_interval);
			the_interval = window.setInterval("countdown()", 996);
		}
		
		else {
			refreshState();
		}
	}
	
	
	else {
		window.clearInterval(the_interval);
		setTimer("MANUALLY");
	}
}


function setTimer(text) {
	document.getElementById('timer').innerHTML = text;
}


function displayLocation() {
	var obj = document.getElementById("location");
	var current = currentLocation ? currentLocation : "unknown";
	
	obj.innerHTML = current;
}

function setupLocations() {
	var locations = new Array();
	if(window.widget) {
		var locationstring = widget.system("./get_locations.pl", null).outputString;
		locations = locationstring.split(/\n/g);
	}
	else {
		locations.push("0	not available");
	}
	
	// empty old locations
	var sel = document.getElementById("change_location_menu");
	while(null != sel.lastChild)
		sel.removeChild(sel.lastChild);
	
	// loop all locations
	for(var i = 0; i < locations.length; i++) {
		// get location info
		var values = locations[i].split(/\t/);
		var selected = (values[0] == 1);
		var value = values[1];
		var name = values[2];
		
		// set up an option-element
		var opt = document.createElement("option");
		opt.value = value;
		opt.innerHTML = name;
		sel.appendChild(opt);
		
		// current location
		if(selected) {
			opt.selected = selected;
			currentLocation = name;
		}
	}
	
	// add option to open Network Prefs and Network Doctor
	var opt1 = document.createElement("option");
	opt1.value = -1;
	opt1.innerHTML = "----";
	sel.appendChild(opt1);
	var opt2 = document.createElement("option");
	opt2.value = -2;
	opt2.innerHTML = "Open Network Preferences";
	sel.appendChild(opt2);
	var opt3 = document.createElement("option");
	opt3.value = -3;
	opt3.innerHTML = "Open Network Diagnostics";
	sel.appendChild(opt3);
	
	displayLocation();
}

// called when a new location is chosen from the drop-down
function changeLocation(id, name) {
	if(window.widget) {
		if(id == -2) {
			widget.openApplication("com.apple.systempreferences");
			return;
		}
		else if(id == -3) {
			widget.openApplication("com.apple.NetworkDiagnostics");
			return;
		}
		else if(id != -1) {
			var set_success = widget.system("./set_location.pl " + id, null).outputString;
			currentLocation = set_success;
		}
	}
	
	setTimeout("refreshState()", 50);
}


function purgeInterfaces() {
	var parent = document.getElementById('maincontent');
	var elements = parent.childNodes;
	var a = elements.length;
	
	for(i = a; i > 0; i--) {
		if(elements[i] && elements[i].nodeName == 'P')
			parent.removeChild(elements[i]);
	}
}

function purgeLastChild(id) {
	var parent = document.getElementById(id);
	parent.removeChild(parent.lastChild);
}


function addParagraph(data_arr, iface, my_class) {
	var parent = document.getElementById('maincontent');
	var data = (typeof(data_arr) == "object") ? data_arr : new Array(data_arr);	// 0 = interface, 1 = IPv4, 2 = IPv6, 3 = prefixlen, 4 = netmask, 5 = broadcast, 6 = MAC
	
	// <p>
	var paragraph = document.createElement("p");
	if(my_class)
		paragraph.setAttribute("class", my_class);
	
	// Interface-Image
	if(iface) {
		var img = document.createElement("img");
		img.setAttribute("src", "Images_" + stylesheet + "/" + iface + ".png");
		img.setAttribute("class", "interface_img");
		img.setAttribute("onclick", "toggleMoreInfo(this.parentNode, event)");
	}
			
	// <a>
	var link = new Array();
	var a = 0;
	for(b = 0; b < data.length; b++) {
		if(data[b].length > 0) {
			link[a] = document.createElement("a");
			
			link[a].setAttribute("href", "javascript:toClipboard('" + data[b] + "')");
			link[a].setAttribute("class", (data.length > 1) ? "data" : "data_big");
			
			var link_data = document.createTextNode(data[b]);
			link[a++].appendChild(link_data);
		}
	}
	
	// combine
	if(link.length > 1) {									// IPv6 and stuff
		for(b = 0; b < link.length; b++) {
			paragraph.appendChild(link[b]);
			
			if(b == 0)
				paragraph.appendChild(document.createTextNode(" | "));
			else if(b == 1) {
				paragraph.appendChild(document.createElement("br"));
				paragraph.appendChild(document.createTextNode("mask "));
			}
			else if(b == 2) {
				paragraph.appendChild(document.createElement("br"));
				paragraph.appendChild(document.createTextNode("b-cast "));
			}
			else if(b == 3 && link.length > 4) {
				paragraph.appendChild(document.createElement("br"));
				paragraph.appendChild(document.createTextNode("MAC "));
			}
		}
	}
	else {
		if(img)
			paragraph.appendChild(img);
		
		// the WAN-IP
		if(link[0])
			paragraph.appendChild(link[0]);
			
		// the Ping-Div
		else {
			var span = document.createElement("span");
			span.setAttribute("id", "ping_packets");
			var span2 = document.createElement("a");
			span2.setAttribute("id", "ping_min");
			span2.setAttribute("class", "data");
			span2.setAttribute("onclick", "javascript:toClipboard(this.innerHTML)");
			span2.innerHTML = "?";
			var span3 = document.createElement("a");
			span3.setAttribute("id", "ping_avg");
			span3.setAttribute("class", "data");
			span3.setAttribute("onclick", "javascript:toClipboard(this.innerHTML)");
			span3.innerHTML = "?";
			var span4 = document.createElement("a");
			span4.setAttribute("id", "ping_max");
			span4.setAttribute("class", "data");
			span4.setAttribute("onclick", "javascript:toClipboard(this.innerHTML)");
			span4.innerHTML = "?";
			
			// put it together
			paragraph.appendChild(document.createTextNode("Ping results" + (pingIP ? " for " + pingIP : '')));
			paragraph.appendChild(document.createElement("br"));
			paragraph.appendChild(span);
			paragraph.appendChild(document.createElement("br"));
			paragraph.appendChild(document.createTextNode("Min / Avg / Max"));
			paragraph.appendChild(document.createElement("br"));
			paragraph.appendChild(span2);
			paragraph.appendChild(document.createTextNode(" ms, "));
			paragraph.appendChild(span3);
			paragraph.appendChild(document.createTextNode(" ms, "));
			paragraph.appendChild(span4);
			paragraph.appendChild(document.createTextNode(" ms"));
			
			// dont hide it
			//paragraph.setAttribute("style", "display:block;");
		}
	}
	
	parent.appendChild(paragraph);
}


function toClipboard(value) {
	if(window.widget) {
		widget.system("./toClipboard.sh '" + value + "'", null);
	}
}






/*
 ******************
 * Pref Functions *
 ******************
 */

function getTimer() {		// get refresh-timer from prefs
	if(window.widget) {
		var value = widget.preferenceForKey("timer");
	}
	
	return value ? value : 7200;
}

function getRefreshMode() {		// get mode from prefs (whilehidden, resume)
	if(window.widget) {
		var value = widget.preferenceForKey("refreshMode");
	}
	
	return value ? value : "whilehidden";
}

function getRefreshOnShow() {		// get from prefs
	if(window.widget) {
		var value = widget.preferenceForKey("refreshOnShow");
	}
	
	return value ? true : false;
}

function getStylesheet() {		// get from prefs
	if(window.widget) {
		var value = widget.preferenceForKey("stylesheet");
	}
	
	return value ? value : 1;
}


function setStylesheet(style) {
	if(! style)
		style = 1;
	
	var stylelink = document.getElementById('stylesheetlink');
	stylelink.href = "./NetworkStat_" + style + ".css";
}

function getPingIP() {		// get from prefs
	if(window.widget) {
		var value = widget.preferenceForKey("pingIP");
	}
	
	return value ? value : "4.2.2.2";
}



function adjustPrefs() {
	// timer
	var myseconds = getTimer();
	var timerelem = document.forms[0].timer;
	
	if(refreshMode == 'manual') {
		timerelem.options[0].selected = true;
	}
	else {
		for(i = 0; i < timerelem.childNodes.length; i++) {
			if(timerelem.options[i].value == myseconds) {
				timerelem.options[i].selected = true;
				break;
			}
		}
	}
	
	// refresh-mode
	checkIfManually();
	if(refreshMode == "whilehidden")
		document.forms[0].refresh.options[0].selected = true;
	else if(refreshMode == "resume")
		document.forms[0].refresh.options[1].selected = true;
	
	// onShow-refresh
	if(refreshOnShow)
		document.forms[0].onshow.checked = true;
	
	// selected stylesheet
	if(getStylesheet() == 3)
		document.forms[0].style[2].checked = true;
	else if(getStylesheet() == 2)
		document.forms[0].style[1].checked = true;
	else
		document.forms[0].style[0].checked = true;
	
	// insert ping-IP
	document.forms[0].ping_ip.value = pingIP;
}


function checkIfManually() {
	if(document.forms[0].timer.selectedIndex == 0) {
		document.forms[0].refresh.disabled = true;
	}
	else {
		document.forms[0].refresh.disabled = false;
	}
}

function savePrefs() {
	// timer
	var timerelem = document.forms[0].timer;
	var timer = timerelem.options[timerelem.selectedIndex].value;
	timer = (timer == 'manual') ? 7200 : timer;
	
	// mode
	if(timerelem.options[timerelem.selectedIndex].value == 'manual')
		var mode = 'manual';
	else if(document.forms[0].refresh[1].selected == true)
		var mode = "resume";
	else
		var mode = "whilehidden";
	
	// onshow
	var onShow = document.forms[0].onshow.checked ? true : false;
	
	// stylesheet
	var style = (document.forms[0].style[2].checked) ? 3 : ((document.forms[0].style[1].checked) ? 2 : 1);
	
	// ping-IP
	var ping_ip = document.forms[0].ping_ip.value.match(/\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}/) ? document.forms[0].ping_ip.value : "4.2.2.2";
	pingIP = ping_ip;
	
	if(window.widget) {
		widget.setPreferenceForKey(timer, "timer");
		widget.setPreferenceForKey(mode, "refreshMode");
		widget.setPreferenceForKey(onShow, "refreshOnShow");
		widget.setPreferenceForKey(style, "stylesheet");
		widget.setPreferenceForKey(ping_ip, "pingIP");
	}
	
	hidePrefs();
}

function showPrefs() {
	var front = document.getElementById("front");
	var back = document.getElementById("back");
	
	// done-button needs black font instead of white if stylesheet is 3
	var element = document.getElementById("done").firstChild.nextSibling;
	var oldstyle = element.getAttribute("style");
	if(stylesheet == 3)
		element.setAttribute("style", oldstyle + "; color:#000;");
	else
		element.setAttribute("style", oldstyle + "; color:#FFF;");
	
	adjustPrefs();
	showVersion();
	
	if(window.widget)
		widget.prepareForTransition("ToBack");
				
	front.style.display = "none";
	back.style.display = "block";
		
	if(window.widget)
		setTimeout("widget.performTransition();", 0);  
}

function switchPrefTab(tab) {
	var found = false;
	var thedivs = new Array("refresh", "style", "ping");
	
	for(var i = 0; i < thedivs.length; i++) {
		if(thedivs[i] == tab) {
			document.getElementById("tab_" + thedivs[i]).setAttribute("class", "tabitem selected");
			document.getElementById("prefsection_" + thedivs[i]).style.display = "block";
			found = true;
		}
		else {
			document.getElementById("tab_" + thedivs[i]).setAttribute("class", "tabitem");
			document.getElementById("prefsection_" + thedivs[i]).style.display = "none";
		}
	}
	
	if(!found) {
		document.getElementById("prefsection_ping").style.display = "block";
	}
}

function hidePrefs() {
	var front = document.getElementById("front");
	var back = document.getElementById("back");
	
	stylesheet = getStylesheet();
	setStylesheet(stylesheet);
	document.getElementById('refreshbutton').src = "Images_" + stylesheet + "/refresh.png";	// set refreshbutton matching stylesheet
	
	seconds = getTimer();
	refreshMode = getRefreshMode();
	refreshOnShow = getRefreshOnShow();
	doCountdown = (refreshMode == 'manual') ? 0 : 1;
	
	if(window.widget)
		widget.prepareForTransition("ToFront");
				
	front.style.display = "block";
	back.style.display = "none";
		
	if(window.widget)
		setTimeout("widget.performTransition();", 0);
	
	setTimeout("refreshState()", 100);
}



//	Localization
/*
function getLocalizedString (key)
{
	try {
		return localizedStrings[key];
	} catch (ex) {}

	return key;
}
*/




/*
 **********
 * Events *
 **********
 */

if(window.widget) {
	widget.onshow = onShow;
	widget.onhide = onHide;
}


function onShow() {
	doCountdown = (refreshMode == 'manual') ? 0 : 1;

	if(refreshOnShow)
		 refreshState();
	
	if(refreshMode == 'resume')		// by now, doCountdown must be 1; else we`re refreshing manually and there needs to be no countdown
		countdown();
	
}

function onHide() {	
	if(refreshMode == 'resume')
		doCountdown = 0;
}



/*
 ********************
 * GUI manipulation *
 ********************
 */


function blendFromTo(from_id, to_id) {
	var from = document.getElementById(from_id);
	var to = document.getElementById(to_id);
	
	if(from && to) {
		from.style.display = 'none';
		to.style.display = 'block';
	}
}


function toggleMoreInfo(obj, event) {
	if(!obj || !obj.nextSibling)
		return;
	
	var moreinfo = obj.nextSibling;
	if(moreinfo == null)
		return;
	
	if(moreinfo.style.display == 'block')
		moreinfo.style.display = 'none';
	else
		moreinfo.style.display = 'block';
	
	adjustTotalSize();
}




var dimensions = new Array();
dimensions[1] = { topheight:54, bottomheight:22, width:250, minheight:140 };
dimensions[2] = { topheight:54, bottomheight:22, width:250, minheight:140 };
dimensions[3] = { topheight:49, bottomheight:18, width:230, minheight:140 };

var resize = { totaltime:300, totallongtime:4000, starttime:null, endtime:null, startsize:0, targetsize:0, windowAdjusted:false };

function adjustTotalSize(longtime) {
	var now = (new Date()).getTime();
	var reference = document.getElementById("maincontent");
	var scale = document.getElementById("main");
	
	resize.startsize = Math.abs(document.defaultView.getComputedStyle(scale).getPropertyValue("height").replace(/px/, ''));
	resize.targetsize = Math.abs(document.defaultView.getComputedStyle(reference).getPropertyValue("height").replace(/px/, ''));
	resize.windowAdjusted = false;
	
	if((resize.startsize < resize.targetsize) && window.widget) {
		var newTotalSize = resize.targetsize + dimensions[stylesheet].topheight + dimensions[stylesheet].bottomheight;
		window.resizeTo(dimensions[stylesheet].width, (newTotalSize < dimensions[stylesheet].minheight) ? dimensions[stylesheet].minheight : newTotalSize); 
		resize.windowAdjusted = true;
	}
	
	resize.starttime = now;
	resize.endtime = now + (longtime ? resize.totallongtime : resize.totaltime);
	
	//alert('resize from ' + resize.startsize + ' to ' + resize.targetsize + ' initiating');
	setTimeout("resizeDiv('main')", 5);
}

function resizeDiv(div) {
	var now = (new Date()).getTime();
	var obj = document.getElementById(div);
	
	// while resizing
	if(now < resize.endtime) {
		var delta = (now - resize.starttime) / resize.totaltime;
		var factor = ((delta * delta) * 3.0) - ((delta * delta * delta) * 2.0);
		var size = (resize.startsize * (1 - factor)) + (resize.targetsize * factor);
		
		obj.style.height = size + "px";
	}
	
	// finishing
	else {
		obj.style.height = resize.targetsize + "px";
		if(!resize.windowAdjusted) {
			var newTotalSize = resize.targetsize + dimensions[stylesheet].topheight + dimensions[stylesheet].bottomheight;
			window.resizeTo(dimensions[stylesheet].width, (newTotalSize < dimensions[stylesheet].minheight) ? dimensions[stylesheet].minheight : newTotalSize);
		}
		return;
	}
	
	setTimeout("resizeDiv('" + div + "')", 10);
}


function formatDate(stamp) {
	if(!stamp)
		stamp = new Date();
	
	var day = stamp.getDate();
	var month = stamp.getMonth() + 1;
	var year = stamp.getFullYear();
	var hour = stamp.getHours();
	hour = (hour < 10) ? "0" + hour : hour;
	var minute = stamp.getMinutes();
	minute = (minute < 10) ? "0" + minute : minute;
	
	var formatted = day + "." + month + "." + year + " " + hour + ":" + minute;
	return formatted;
}



/*
 **************
 *  by Apple  *
 **************
 */

var flipShown = false;
var animation = { duration:0, starttime:0, to:1.0, now:0.0, from:0.0, firstElement:null, timer:null };

function mousemove(event) {
	if(!flipShown) {
		if (animation.timer != null) {
			clearInterval(animation.timer);
			animation.timer = null;
		}
 
		var starttime = (new Date).getTime() - 13;
 
		animation.duration = 500;
		animation.starttime = starttime;
		animation.firstElement = document.getElementById('flip');
		animation.timer = setInterval("animate();", 13);
		animation.from = animation.now;
		animation.to = 1.0;
		animate();
		flipShown = true;
	}
}


function mouseexit(event) {
	if(flipShown) {
		
		// fade out the info button
		if (animation.timer != null)
		{
			clearInterval (animation.timer);
			animation.timer  = null;
		}

		var starttime = (new Date).getTime() - 13;

		animation.duration = 500;
		animation.starttime = starttime;
		animation.firstElement = document.getElementById('flip');
		animation.timer = setInterval ("animate();", 13);
		animation.from = animation.now;
		animation.to = 0.0;
		animate();
		flipShown = false;
	}
}

function animate() {
	var T;
	var ease;
	var time = (new Date).getTime();
	
	T = limit_3(time-animation.starttime, 0, animation.duration);

	if (T >= animation.duration) {
		clearInterval (animation.timer);
		animation.timer = null;
		animation.now = animation.to;
	}
	else {
		ease = 0.5 - (0.5 * Math.cos(Math.PI * T / animation.duration));
		animation.now = computeNextFloat (animation.from, animation.to, ease);
	}

	animation.firstElement.style.opacity = animation.now;
}

function limit_3(a, b, c) {
	return a < b ? b : (a > c ? c : a);
}

function computeNextFloat(from, to, ease) {
	return from + (to - from) * ease;
}


// these functions are called when the info button itself receives onmouseover and onmouseout events (by Apple)

function enterflip(event) {
	document.getElementById("fliprollie").style.display = "block";
}

function exitflip(event) {
	document.getElementById("fliprollie").style.display = "none";
}




